Installation
============

Requirements
------------

* Python_ 3.8 or newer
* NumPy_ 1.11.0 or newer
* SciPy_ 0.18.8 or newer
* Scikit-learn_ 0.24.2 
* importlib-metadata_ 0.12
* rmsd_ 1.4
* PySCF_ 2.0.0

.. _Python: https://www.python.org/
.. _NumPy: https://docs.scipy.org/doc/numpy/reference/
.. _SciPy: https://docs.scipy.org/doc/scipy/reference/
.. _Scikit-learn: https://scikit-learn.org/stable/
.. _importlib-metadata : https://pypi.org/project/importlib-metadata/
.. _rmsd : https://pypi.org/project/rmsd/
.. _PySCF : https://pyscf.org/

Installation from source
------------------------

You can get the source from gitlab like this::

    $ git clone https://gitlab.com/pavanello-research-group/qmlearn.git
    $ python -m pip install ./qmlearn

or simpler::

    $ python -m pip install git+https://gitlab.com/pavanello-research-group/qmlearn.git

You can find a Video Tutorial :ref:`here <installqmlearn>`.

